@@ -111,7 +111,9 @@ def test_bucket_update_labels(storage_client, buckets_to_delete):
     assert bucket.labels == new_labels
 
     bucket.labels = {}
-    bucket.update()
+    # See https://github.com/googleapis/python-storage/issues/541
+    retry_400 = _helpers.RetryErrors(exceptions.BadRequest)
+    retry_400(bucket.update)()
     assert bucket.labels == {}
 
 
@@ -565,7 +567,7 @@ def test_bucket_w_retention_period(
     assert not bucket.default_event_based_hold
     assert not bucket.retention_policy_locked
 
-    other.reload()
+    _helpers.retry_no_event_based_hold(other.reload)()
 
     assert not other.event_based_hold
     assert not other.temporary_hold
@@ -704,7 +706,7 @@ def test_new_bucket_w_ubla(
         bucket_acl.reload()
 
     bucket_acl.loaded = True  # Fake that we somehow loaded the ACL
-    bucket_acl.all().grant_read()
+    bucket_acl.group("cloud-developer-relations@google.com").grant_read()
     with pytest.raises(exceptions.BadRequest):
         bucket_acl.save()
 
@@ -722,7 +724,7 @@ def test_new_bucket_w_ubla(
         blob_acl.reload()
 
     blob_acl.loaded = True  # Fake that we somehow loaded the ACL
-    blob_acl.all().grant_read()
+    blob_acl.group("cloud-developer-relations@google.com").grant_read()
     with pytest.raises(exceptions.BadRequest):
         blob_acl.save()
 
